==> haskell-cryptohash-0.11.9-51-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash
version: 0.11.9
id: cryptohash-0.11.9-3kMjAXXN1TD3Uhr9A2UdNu
key: cryptohash-0.11.9-3kMjAXXN1TD3Uhr9A2UdNu
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-cryptohash
synopsis: collection of crypto hashes, fast, pure and practical
description:
    DEPRECATED: this library is still fully functional, but please use cryptonite for new projects
    and convert old one to use cryptonite. This is where things are at nowadays.
    .
    A collection of crypto hashes, with a practical incremental and one-pass, pure APIs,
    with performance close to the fastest implementations available in other languages.
    .
    The implementations are made in C with a haskell FFI wrapper that hide the C implementation.
    .
    Simple examples using the unified API:
    .
    > import Crypto.Hash
    >
    > sha1 :: ByteString -> Digest SHA1
    > sha1 = hash
    >
    > hexSha3_512 :: ByteString -> String
    > hexSha3_512 bs = show (hash bs :: Digest SHA3_512)
    .
    Simple examples using the module API:
    .
    > import qualified Crypto.Hash.SHA1 as SHA1
    >
    > main = putStrLn $ show $ SHA1.hash (Data.ByteString.pack [0..255])
    .
    > import qualified Crypto.Hash.SHA3 as SHA3
    >
    > main = putStrLn $ show $ digest
    >   where digest = SHA3.finalize ctx
    >         ctx    = foldl'\'' SHA3.update iCtx (map Data.ByteString.pack [ [1,2,3], [4,5,6] ]
    >         iCtx   = SHA3.init 224
category: Data, Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Crypto.Hash Crypto.Hash.MD2 Crypto.Hash.MD4 Crypto.Hash.MD5
    Crypto.Hash.RIPEMD160 Crypto.Hash.SHA1 Crypto.Hash.SHA224
    Crypto.Hash.SHA256 Crypto.Hash.SHA3 Crypto.Hash.SHA384
    Crypto.Hash.SHA512 Crypto.Hash.SHA512t Crypto.Hash.Skein256
    Crypto.Hash.Skein512 Crypto.Hash.Tiger Crypto.Hash.Types
    Crypto.Hash.Whirlpool Crypto.MAC Crypto.MAC.HMAC Crypto.MAC.SHA3
hidden-modules: Crypto.Hash.Internal
abi: 0db6ce7031650ce359ebb858f21b87d4
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cryptohash-0.11.9
library-dirs: /usr/lib/ghc-8.2.2/site-local/cryptohash-0.11.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/cryptohash-0.11.9
hs-libraries: HScryptohash-0.11.9-3kMjAXXN1TD3Uhr9A2UdNu
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL
    cryptonite-0.24-6Ygp664jBWE3FIr3r0Uq44
    memory-0.14.16-JXoliazMy4LBu5xxL66kmR ghc-prim-0.5.1.1
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL=24171e0673b6d1cdc40be4d3c9a33c0e
             cryptonite-0.24-6Ygp664jBWE3FIr3r0Uq44=eea3e1c865d0eecd53f47427ac255e06
             memory-0.14.16-JXoliazMy4LBu5xxL66kmR=ab65a51ef395f4cd2a78138a2eaca54b
             ghc-prim-0.5.1.1=c8f3d173544d1472727fce7b0518abda
haddock-interfaces: /usr/share/doc/haskell-cryptohash/html/cryptohash.haddock
haddock-html: /usr/share/doc/haskell-cryptohash/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-0.11.9-61-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash
version: 0.11.9
id: cryptohash-0.11.9-2U8R2Lw6pujHMn8zue6cAL
key: cryptohash-0.11.9-2U8R2Lw6pujHMn8zue6cAL
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-cryptohash
synopsis: collection of crypto hashes, fast, pure and practical
description:
    DEPRECATED: this library is still fully functional, but please use cryptonite for new projects
    and convert old one to use cryptonite. This is where things are at nowadays.
    .
    A collection of crypto hashes, with a practical incremental and one-pass, pure APIs,
    with performance close to the fastest implementations available in other languages.
    .
    The implementations are made in C with a haskell FFI wrapper that hide the C implementation.
    .
    Simple examples using the unified API:
    .
    > import Crypto.Hash
    >
    > sha1 :: ByteString -> Digest SHA1
    > sha1 = hash
    >
    > hexSha3_512 :: ByteString -> String
    > hexSha3_512 bs = show (hash bs :: Digest SHA3_512)
    .
    Simple examples using the module API:
    .
    > import qualified Crypto.Hash.SHA1 as SHA1
    >
    > main = putStrLn $ show $ SHA1.hash (Data.ByteString.pack [0..255])
    .
    > import qualified Crypto.Hash.SHA3 as SHA3
    >
    > main = putStrLn $ show $ digest
    >   where digest = SHA3.finalize ctx
    >         ctx    = foldl'\'' SHA3.update iCtx (map Data.ByteString.pack [ [1,2,3], [4,5,6] ]
    >         iCtx   = SHA3.init 224
category: Data, Cryptography
abi: 6d22c4f6ce25d6829f67cd55557d846e
exposed: True
exposed-modules:
    Crypto.Hash Crypto.Hash.MD2 Crypto.Hash.MD4 Crypto.Hash.MD5
    Crypto.Hash.RIPEMD160 Crypto.Hash.SHA1 Crypto.Hash.SHA224
    Crypto.Hash.SHA256 Crypto.Hash.SHA3 Crypto.Hash.SHA384
    Crypto.Hash.SHA512 Crypto.Hash.SHA512t Crypto.Hash.Skein256
    Crypto.Hash.Skein512 Crypto.Hash.Tiger Crypto.Hash.Types
    Crypto.Hash.Whirlpool Crypto.MAC Crypto.MAC.HMAC Crypto.MAC.SHA3
hidden-modules: Crypto.Hash.Internal
import-dirs: /usr/lib/ghc-8.4.2/site-local/cryptohash-0.11.9
library-dirs: /usr/lib/ghc-8.4.2/site-local/cryptohash-0.11.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/cryptohash-0.11.9
hs-libraries: HScryptohash-0.11.9-2U8R2Lw6pujHMn8zue6cAL
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY
    cryptonite-0.25-90uxV0bWEYmfC6QouwM7s
    memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi ghc-prim-0.5.2.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
             byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY=92b5e3ef28899454b801dbff33965e76
             cryptonite-0.25-90uxV0bWEYmfC6QouwM7s=fe88b1a2ffec9ea7c1970408b9b1825d
             memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi=ed2d5adcedeb6833cc2a392fb853e830
             ghc-prim-0.5.2.0=a22477c99003a90dd639dbfd07997615
haddock-interfaces: /usr/share/doc/haskell-cryptohash/html/cryptohash.haddock
haddock-html: /usr/share/doc/haskell-cryptohash/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
